scanpydoc |pypi| |docs| |travis| |codecov|
==========================================

A collection of Sphinx extensions similar to (but more flexible than) numpydoc.

Check the self-documenting documentation at https://icb-scanpydoc.readthedocs-hosted.com

.. |pypi| image:: https://img.shields.io/pypi/v/scanpydoc.svg
   :target: https://pypi.org/project/scanpydoc/
.. |docs| image:: https://readthedocs.com/projects/icb-scanpydoc/badge/
   :target: https://icb-scanpydoc.readthedocs-hosted.com/
.. |travis| image:: https://travis-ci.com/theislab/scanpydoc.svg
   :target: https://travis-ci.com/theislab/scanpydoc
.. |codecov| image:: https://codecov.io/gh/theislab/scanpydoc/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/theislab/scanpydoc
